@@ -8,20 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_apigateway._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-apigateway-sagemakerendpoint",
-    "1.172.0",
+    "2.5.0",
     __name__[0:-6],
-    "aws-apigateway-sagemakerendpoint@1.172.0.jsii.tgz",
+    "aws-apigateway-sagemakerendpoint@2.5.0.jsii.tgz",
 )
 
 __all__ = [
